@@ -27,8 +27,8 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QPushButton>
+#include <QRandomGenerator>
 #include <QWidget>
-#include "Common.h"
 #include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
 
@@ -56,7 +56,7 @@ bool ButtonParameter::addTo(QWidget * widget, int row)
   _pushButton = new QPushButton(_text, widget);
   _pushButton->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
   _grid->addWidget(_pushButton, row, 0, 1, 3, _alignment);
-  connect(_pushButton, SIGNAL(clicked(bool)), this, SLOT(onPushButtonClicked(bool)));
+  connectButton();
   return true;
 }
 
@@ -82,19 +82,36 @@ void ButtonParameter::clear()
 
 void ButtonParameter::reset() {}
 
-void ButtonParameter::onPushButtonClicked(bool)
+void ButtonParameter::randomize()
+{
+  if (acceptRandom()) {
+    _value = QRandomGenerator::global()->bounded(0, 2);
+  }
+}
+
+void ButtonParameter::onPushButtonClicked(bool /* checked */)
 {
   _value = true;
   notifyIfRelevant();
 }
 
-bool ButtonParameter::initFromText(const char * text, int & textLength)
+void ButtonParameter::connectButton()
+{
+  connect(_pushButton, &QPushButton::clicked, this, &ButtonParameter::onPushButtonClicked);
+}
+
+void ButtonParameter::disconnectButton()
+{
+  _pushButton->disconnect(this);
+}
+
+bool ButtonParameter::initFromText(const QString & filterName, const char * text, int & textLength)
 {
   QList<QString> list = parseText("button", text, textLength);
   if (list.isEmpty()) {
     return false;
   }
-  _text = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
+  _text = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0], filterName));
   QString & alignment = list[1];
   if (alignment.isEmpty()) {
     return true;
